@@ -225,96 +225,6 @@ double GetCurrentTimeInMicroseconds() {
   return kMicrosecondsPerSecond * tv.tv_sec + tv.tv_usec;
 }
 
-int WriteFileSync(const char* path, uv_buf_t buf) {
-  return WriteFileSync(path, &buf, 1);
-}
-
-int WriteFileSync(const char* path, uv_buf_t* bufs, size_t buf_count) {
-  uv_fs_t req;
-  int fd = uv_fs_open(nullptr,
-                      &req,
-                      path,
-                      O_WRONLY | O_CREAT | O_TRUNC,
-                      S_IWUSR | S_IRUSR,
-                      nullptr);
-  uv_fs_req_cleanup(&req);
-  if (fd < 0) {
-    return fd;
-  }
-
-  int err = uv_fs_write(nullptr, &req, fd, bufs, buf_count, 0, nullptr);
-  uv_fs_req_cleanup(&req);
-  if (err < 0) {
-    return err;
-  }
-
-  err = uv_fs_close(nullptr, &req, fd, nullptr);
-  uv_fs_req_cleanup(&req);
-  return err;
-}
-
-int WriteFileSync(v8::Isolate* isolate,
-                  const char* path,
-                  v8::Local<v8::String> string) {
-  node::Utf8Value utf8(isolate, string);
-  uv_buf_t buf = uv_buf_init(utf8.out(), utf8.length());
-  return WriteFileSync(path, buf);
-}
-
-int ReadFileSync(std::string* result, const char* path) {
-  uv_fs_t req;
-  auto defer_req_cleanup = OnScopeLeave([&req]() {
-    uv_fs_req_cleanup(&req);
-  });
-
-  uv_file file = uv_fs_open(nullptr, &req, path, O_RDONLY, 0, nullptr);
-  if (req.result < 0) {
-    // req will be cleaned up by scope leave.
-    return req.result;
-  }
-  uv_fs_req_cleanup(&req);
-
-  auto defer_close = OnScopeLeave([file]() {
-    uv_fs_t close_req;
-    CHECK_EQ(0, uv_fs_close(nullptr, &close_req, file, nullptr));
-    uv_fs_req_cleanup(&close_req);
-  });
-
-  *result = std::string("");
-  char buffer[4096];
-  uv_buf_t buf = uv_buf_init(buffer, sizeof(buffer));
-
-  while (true) {
-    const int r =
-        uv_fs_read(nullptr, &req, file, &buf, 1, result->length(), nullptr);
-    if (req.result < 0) {
-      // req will be cleaned up by scope leave.
-      return req.result;
-    }
-    uv_fs_req_cleanup(&req);
-    if (r <= 0) {
-      break;
-    }
-    result->append(buf.base, r);
-  }
-  return 0;
-}
-
-std::vector<char> ReadFileSync(FILE* fp) {
-  CHECK_EQ(ftell(fp), 0);
-  int err = fseek(fp, 0, SEEK_END);
-  CHECK_EQ(err, 0);
-  size_t size = ftell(fp);
-  CHECK_NE(size, static_cast<size_t>(-1L));
-  err = fseek(fp, 0, SEEK_SET);
-  CHECK_EQ(err, 0);
-
-  std::vector<char> contents(size);
-  size_t num_read = fread(contents.data(), size, 1, fp);
-  CHECK_EQ(num_read, 1);
-  return contents;
-}
-
 void DiagnosticFilename::LocalTime(TIME_TYPE* tm_struct) {
 #ifdef _WIN32
   GetLocalTime(tm_struct);
